@@ -4,6 +4,7 @@ const MAX_SUBSTRING_LIMIT = 100;
 const ANIMATION_TIME = 200;
 const FETCH_RESULTS_DELAY = 250;
 const CLEAR_RESULTS_DELAY = 300;
+const RTD_SEARCH_PARAMETER  = "rtd_search";
 
 /**
  * Debounce the function.
@@ -41,51 +42,46 @@ const debounce = (func, wait) => {
 
 
 /**
- * Wrapper around underscorejs's template function.
- * 
- * This is to make it work with new and old versions.
- */
-const render_template = (template, data) => {
-    // pre-1.7 syntax from underscorejs.
-    let result = $u.template(template, data);
-    if (typeof result === 'function') {
-        // New syntax.
-        result = $u.template(template)(data);
-    }
-    return result;
-};
+  * Build a section with its matching results.
+  *
+  * A section has the form:
+  *
+  *   <a href="{link}">
+  *     <div class="outer_div_page_results" id="{id}">
+  *       <span class="search__result__subheading">
+  *         {title}
+  *       </span>
+  *       <p class="search__result__content">
+  *         {contents[0]}
+  *       </p>
+  *       <p class="search__result__content">
+  *         {contents[1]}
+  *       </p>
+  *       ...
+  *     </div>
+  *   </a>
+  *
+  * @param {String} id.
+  * @param {String} title.
+  * @param {String} link.
+  * @param {Array} contents.
+  */
+const buildSection = function (id, title, link, contents) {
+    let span_element = createDomNode("span", {class: "search__result__subheading"});
+    span_element.innerHTML = title;
 
-/**
- * Take an object as parameter and convert it to
- * url params string.
- *
- * Eg. if ``obj = { 'a': 1, 'b': 2, 'c': ['hello', 'world'] }``, then it will return
- * the string ``a=1&b=2&c=hello,world``
- *
- * @param {Object} obj the object to be converted
- * @return {String|Array} object in url params form
- */
-const convertObjToUrlParams = obj => {
-    let params = Object.keys(obj).map(function(key) {
-        if (_is_string(key)) {
-            const s = key + "=" + encodeURI(obj[key]);
-            return s;
-        }
-    });
+    let div_element = createDomNode("div", {class: "outer_div_page_results", id: id});
+    div_element.appendChild(span_element);
 
-    // removing empty strings from the 'params' array
-    let final_params = [];
-    for (let i = 0; i < params.length; ++i) {
-        if (_is_string(params[i])) {
-            final_params.push(params[i]);
-        }
-    }
-    if (final_params.length === 1) {
-        return final_params[0];
-    } else {
-        let final_url_params = final_params.join("&");
-        return final_url_params;
+    for (var i = 0; i < contents.length; i += 1) {
+        let p_element = createDomNode("p", {class: "search__result__content"});
+        p_element.innerHTML = contents[i];
+        div_element.appendChild(p_element);
     }
+
+    let section = createDomNode("a", {href: link});
+    section.appendChild(div_element);
+    return section;
 };
 
 
@@ -93,31 +89,16 @@ const convertObjToUrlParams = obj => {
  * Adds/removes "rtd_search" url parameter to the url.
  */
 const updateUrl = () => {
-    let origin = window.location.origin;
-    let path = window.location.pathname;
-    let url_params = $.getQueryParameters();
-    let hash = window.location.hash;
+    let parsed_url = new URL(window.location.href);
     let search_query = getSearchTerm();
-    // search_query should not be an empty string
+    // search_query should not be an empty string.
     if (search_query.length > 0) {
-        url_params.rtd_search = search_query;
+        parsed_url.searchParams.set(RTD_SEARCH_PARAMETER, search_query);
     } else {
-        delete url_params.rtd_search;
+        parsed_url.searchParams.delete(RTD_SEARCH_PARAMETER);
     }
-
-    let window_location_search = convertObjToUrlParams(url_params) + hash;
-
-    // this happens during the tests,
-    // when window.location.origin is "null" in Firefox
-    // then correct URL is contained by window.location.pathname
-    // which starts with "file://"
-    let url = path + "?" + window_location_search;
-    if (origin.substring(0, 4) === "http") {
-        url = origin + url;
-    }
-
-    // update url
-    window.history.pushState({}, null, url);
+    // Update url.
+    window.history.pushState({}, null, parsed_url.toString());
 };
 
 
@@ -152,8 +133,10 @@ const isModalVisible = () => {
  */
 const createDomNode = (nodeName, attributes) => {
     let node = document.createElement(nodeName);
-    for (let attr in attributes) {
-        node.setAttribute(attr, attributes[attr]);
+    if (attributes !== null) {
+        for (let attr in attributes) {
+            node.setAttribute(attr, attributes[attr]);
+        }
     }
     return node;
 };
@@ -172,18 +155,6 @@ const _is_string = str => {
     }
 };
 
-/**
- * Checks if data type is a non-empty array
- * @param {*} data data whose type is to be checked
- * @return {Boolean} returns true if data is non-empty array, else returns false
- */
-const _is_array = arr => {
-    if (Array.isArray(arr) && arr.length > 0) {
-        return true;
-    } else {
-        return false;
-    }
-};
 
 /**
  * Generate and return html structure
@@ -194,21 +165,6 @@ const _is_array = arr => {
  * @param {Number} id to be used in for this section
  */
 const get_section_html = (sectionData, page_link, id) => {
-    let section_template =
-        '<a href="<%= section_link %>"> \
-            <div class="outer_div_page_results" id="<%= section_id %>"> \
-                <span class="search__result__subheading"> \
-                    <%= section_subheading %> \
-                </span> \
-                <% for (var i = 0; i < section_content.length; ++i) { %> \
-                    <p class="search__result__content"> \
-                        <%= section_content[i] %> \
-                    </p> \
-                <% } %>\
-            </div> \
-        </a> \
-        <br class="br-for-hits">';
-
     let section_subheading = sectionData.title;
     let highlights = sectionData.highlights;
     if (highlights.title.length) {
@@ -232,17 +188,8 @@ const get_section_html = (sectionData, page_link, id) => {
     }
 
     let section_link = `${page_link}#${sectionData.id}`;
-
     let section_id = "hit__" + id;
-
-    let section_html = render_template(section_template, {
-        section_link: section_link,
-        section_id: section_id,
-        section_subheading: section_subheading,
-        section_content: section_content
-    });
-
-    return section_html;
+    return buildSection(section_id, section_subheading, section_link, section_content);
 };
 
 /**
@@ -254,20 +201,6 @@ const get_section_html = (sectionData, page_link, id) => {
  * @param {Number} id to be used in for this section
  */
 const get_domain_html = (domainData, page_link, id) => {
-    let domain_template =
-        '<a href="<%= domain_link %>"> \
-            <div class="outer_div_page_results" id="<%= domain_id %>"> \
-                <span class="search__result__subheading"> \
-                    <%= domain_subheading %> \
-                    <div class="search__domain_role_name"> \
-                        <%= domain_role_name %> \
-                    </div> \
-                </span> \
-                <p class="search__result__content"><%= domain_content %></p> \
-            </div> \
-        </a> \
-        <br class="br-for-hits">';
-
     let domain_link = `${page_link}#${domainData.id}`;
     let domain_role_name = domainData.role;
     let domain_name = domainData.name;
@@ -283,37 +216,50 @@ const get_domain_html = (domainData, page_link, id) => {
     }
 
     let domain_id = "hit__" + id;
-    domain_role_name = "[" + domain_role_name + "]";
 
-    let domain_html = render_template(domain_template, {
-        domain_link: domain_link,
-        domain_id: domain_id,
-        domain_content: domain_content,
-        domain_subheading: domain_name,
-        domain_role_name: domain_role_name
-    });
+    let div_role_name = createDomNode("div", {class: "search__domain_role_name"});
+    div_role_name.innerText = `[${domain_role_name}]`;
+    domain_name += div_role_name.outerHTML;
 
-    return domain_html;
+    return buildSection(
+        domain_id,
+        domain_name,
+        domain_link,
+        [domain_content]
+    );
 };
 
+
 /**
  * Generate search results for a single page.
  *
+ * This has the form:
+ *   <div>
+ *     <a href="{link}">
+ *       <h2 class="search__result__title">
+ *         {title}
+ *         <small class="rtd_ui_search_subtitle">{subtitle}</small>
+ *         <br/>
+ *       </h2>
+ *     </a>
+ *
+ *     <a href="{link}">
+ *       {section}
+ *     </a>
+ *     <br class="br-for-hits" />
+ *
+ *     <a href="{link}">
+ *       {section}
+ *     </a>
+ *     <br class="br-for-hits" />
+ *   </div>
+ *
  * @param {Object} resultData search results of a page
  * @param {String} projectName
  * @param {Number} id from the last section
  * @return {Object} a <div> node with the results of a single page
  */
 const generateSingleResult = (resultData, projectName, id) => {
-    let content = createDomNode("div");
-
-    let page_link_template =
-        '<a href="<%= page_link %>"> \
-            <h2 class="search__result__title"> \
-                <%= page_title %> \
-            </h2> \
-        </a>';
-
     let page_link = resultData.path;
     let page_title = resultData.title;
     let highlights = resultData.highlights;
@@ -322,47 +268,47 @@ const generateSingleResult = (resultData, projectName, id) => {
         page_title = highlights.title[0];
     }
 
-    // if result is not from the same project,
-    // then it must be from subproject.
+    let h2_element = createDomNode("h2", {class: "search__result__title"});
+    h2_element.innerHTML = page_title;
+
+    // If the result is not from the same project,
+    // then it's from a subproject.
     if (projectName !== resultData.project) {
-        page_title +=
-            " " +
-            render_template(
-                '<small class="rtd_ui_search_subtitle"> \
-                    (from project <%= project %>) \
-                </small>',
-                {
-                    project: resultData.project
-                }
-            );
+        let subtitle = createDomNode("small", {class: "rtd_ui_search_subtitle"});
+        subtitle.innerText = `(from project ${resultData.project})`;
+        h2_element.appendChild(subtitle);
     }
+    h2_element.appendChild(createDomNode("br"))
 
-    page_title += "<br>";
+    let a_element = createDomNode("a", {href: page_link});
+    a_element.appendChild(h2_element);
 
-    content.innerHTML += render_template(page_link_template, {
-        page_link: page_link,
-        page_title: page_title
-    });
+    let content = createDomNode("div");
+    content.appendChild(a_element);
 
+    let separator = createDomNode("br", {class: "br-for-hits"});
     for (let i = 0; i < resultData.blocks.length; ++i) {
         let block = resultData.blocks[i];
-        let html_structure = "";
-
+        let section = null;
         id += 1;
         if (block.type === "section") {
-            html_structure = get_section_html(
+            section = get_section_html(
                 block,
                 page_link,
                 id,
             );
         } else if (block.type === "domain") {
-            html_structure = get_domain_html(
+            section = get_domain_html(
                 block,
                 page_link,
                 id,
             );
         }
-        content.innerHTML += html_structure;
+
+        if (section !== null) {
+          content.appendChild(section);
+          content.appendChild(separator);
+        }
     }
     return content;
 };
@@ -538,11 +484,12 @@ const getErrorDiv = err_msg => {
  * and appends the results to <div class="search__outer"> node,
  * which is already created when the page was loaded.
  *
- * @param {String} search_url url on which request will be sent
- * @param {String} projectName name (slug) of the project
+ * @param {String} api_endpoint: API endpoint
+ * @param {Object} parameters: search parameters
+ * @param {String} projectName: name (slug) of the project
  * @return {Function} debounced function with debounce time of 500ms
  */
-const fetchAndGenerateResults = (search_url, projectName) => {
+const fetchAndGenerateResults = (api_endpoint, parameters, projectName) => {
     let search_outer = document.querySelector(".search__outer");
 
     // Removes all results (if there is any),
@@ -553,52 +500,48 @@ const fetchAndGenerateResults = (search_url, projectName) => {
     search_loding.innerHTML = "<strong>Searching ....</strong>";
     search_outer.appendChild(search_loding);
 
-    let ajaxFunc = () => {
+    let fetchFunc = () => {
         // Update URL just before fetching the results
         updateUrl();
         updateSearchBar();
 
-        $.ajax({
-            url: search_url,
-            crossDomain: true,
-            xhrFields: {
-                withCredentials: true
-            },
-            complete: (resp, status_code) => {
-                if (
-                    status_code === "success" ||
-                    typeof resp.responseJSON !== "undefined"
-                ) {
-                    if (resp.responseJSON.results.length > 0) {
-                        let search_result_box = generateSuggestionsList(
-                            resp.responseJSON,
-                            projectName
-                        );
-                        removeResults();
-                        search_outer.appendChild(search_result_box);
+        const url = api_endpoint + "?" + new URLSearchParams(parameters).toString();
 
-                        // remove active classes from all suggestions
-                        // if the mouse hovers, otherwise styles from
-                        // :hover and .active will clash.
-                        search_outer.addEventListener("mouseenter", e => {
-                            removeAllActive();
-                        });
-                    } else {
-                        removeResults();
-                        let err_div = getErrorDiv("No results found");
-                        search_outer.appendChild(err_div);
-                    }
-                }
-            },
-            error: (resp, status_code, error) => {
+        fetch(url, {method: "GET"})
+        .then(response => {
+            if (!response.ok) {
+              throw new Error();
+            }
+            return response.json();
+        })
+        .then(data => {
+            if (data.results.length > 0) {
+                let search_result_box = generateSuggestionsList(
+                    data,
+                    projectName
+                );
                 removeResults();
-                let err_div = getErrorDiv("There was an error. Please try again.");
+                search_outer.appendChild(search_result_box);
+
+                // remove active classes from all suggestions
+                // if the mouse hovers, otherwise styles from
+                // :hover and .active will clash.
+                search_outer.addEventListener("mouseenter", e => {
+                    removeAllActive();
+                });
+            } else {
+                removeResults();
+                let err_div = getErrorDiv("No results found");
                 search_outer.appendChild(err_div);
             }
+        })
+        .catch(error => {
+            removeResults();
+            let err_div = getErrorDiv("There was an error. Please try again.");
+            search_outer.appendChild(err_div);
         });
     };
-    ajaxFunc = debounce(ajaxFunc, FETCH_RESULTS_DELAY);
-    return ajaxFunc;
+    return debounce(fetchFunc, FETCH_RESULTS_DELAY);
 };
 
 /**
@@ -643,7 +586,7 @@ const showSearchModal = custom_query => {
     // removes previous results (if there are any).
     removeResults();
 
-    $(".search__outer__wrapper").fadeIn(ANIMATION_TIME, () => {
+    let show_modal = function () {
         // removes the focus from the initial input field
         // which as already present in the docs.
         let search_bar = getInputField();
@@ -665,7 +608,17 @@ const showSearchModal = custom_query => {
             }
             search_outer_input.focus();
         }
-    });
+    };
+    
+    if (window.jQuery) {
+      $(".search__outer__wrapper").fadeIn(ANIMATION_TIME, show_modal);
+    } else {
+      let element = document.querySelector(".search__outer__wrapper");
+      if (element && element.style) {
+        element.style.display = "block";
+      }
+      show_modal();
+    }
 };
 
 /**
@@ -687,7 +640,14 @@ const removeSearchModal = () => {
     // update url (remove 'rtd_search' param)
     updateUrl();
 
-    $(".search__outer__wrapper").fadeOut(ANIMATION_TIME);
+    if (window.jQuery) {
+      $(".search__outer__wrapper").fadeOut(ANIMATION_TIME);
+    } else {
+      let element = document.querySelector(".search__outer__wrapper");
+      if (element && element.style) {
+        element.style.display = "none";
+      }
+    }
 };
 
 window.addEventListener("DOMContentLoaded", () => {
@@ -696,7 +656,6 @@ window.addEventListener("DOMContentLoaded", () => {
     if (window.hasOwnProperty("READTHEDOCS_DATA")) {
         const project = READTHEDOCS_DATA.project;
         const version = READTHEDOCS_DATA.version;
-        const language = READTHEDOCS_DATA.language || "en";
         const api_host = READTHEDOCS_DATA.proxied_api_host || '/_';
 
         let initialHtml = generateAndReturnInitialHtml();
@@ -720,25 +679,18 @@ window.addEventListener("DOMContentLoaded", () => {
 
         search_outer_input.addEventListener("input", e => {
             let search_query = getSearchTerm();
-
-            let search_params = {
-                q: search_query,
-                project: project,
-                version: version,
-                language: language,
-            };
-
-            const search_url =
-                api_host +
-                "/api/v2/search/?" +
-                convertObjToUrlParams(search_params);
-
             if (search_query.length > 0) {
                 if (current_request !== null) {
                     // cancel previous ajax request.
                     current_request.cancel();
                 }
-                current_request = fetchAndGenerateResults(search_url, project);
+                const search_endpoint = api_host + "/api/v2/search/";
+                const search_params = {
+                    q: search_query,
+                    project: project,
+                    version: version,
+                };
+                current_request = fetchAndGenerateResults(search_endpoint, search_params, project);
                 current_request();
             } else {
                 // if the last request returns the results,
@@ -825,9 +777,9 @@ window.addEventListener("DOMContentLoaded", () => {
         // if "rtd_search" is present in URL parameters,
         // then open the search modal and show the results
         // for the value of "rtd_search"
-        let url_params = $.getQueryParameters();
-        if (_is_array(url_params.rtd_search)) {
-            let query = decodeURIComponent(url_params.rtd_search);
+        const url_params = new URLSearchParams(document.location.search);
+        const query = url_params.get(RTD_SEARCH_PARAMETER);
+        if (query !== null) {
             showSearchModal(query);
             search_outer_input.value = query;
 
